diff mbox

[PATCHv2,1.8,9/9] qemu-img: increase min_sparse to 128 sectors (64kb)

Message ID 1385456183-24840-10-git-send-email-pl@kamp.de
State New
Headers show

Commit Message

Peter Lieven Nov. 26, 2013, 8:56 a.m. UTC
Suggested-by: Paolo Bonzini <pbonzini@redhat.com>
Signed-off-by: Peter Lieven <pl@kamp.de>
---
 qemu-img.c    |    4 ++--
 qemu-img.texi |    2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

Comments

Paolo Bonzini Nov. 26, 2013, 9:51 a.m. UTC | #1
Il 26/11/2013 09:56, Peter Lieven ha scritto:
> Suggested-by: Paolo Bonzini <pbonzini@redhat.com>
> Signed-off-by: Peter Lieven <pl@kamp.de>
> ---
>  qemu-img.c    |    4 ++--
>  qemu-img.texi |    2 +-
>  2 files changed, 3 insertions(+), 3 deletions(-)
> 
> diff --git a/qemu-img.c b/qemu-img.c
> index cc7540f..6f1179b 100644
> --- a/qemu-img.c
> +++ b/qemu-img.c
> @@ -101,7 +101,7 @@ static void help(void)
>             "  '-p' show progress of command (only certain commands)\n"
>             "  '-pp' show progress of command in sectors (only convert command)\n"
>             "  '-q' use Quiet mode - do not print any output (except errors)\n"
> -           "  '-S' indicates the consecutive number of bytes (defaults to 4k) that must\n"
> +           "  '-S' indicates the consecutive number of bytes (defaults to 64k) that must\n"
>             "       contain only zeros for qemu-img to create a sparse image during\n"
>             "       conversion. If the number of bytes is 0, the source will not be scanned for\n"
>             "       unallocated or zero sectors, and the destination image will always be\n"
> @@ -1158,7 +1158,7 @@ static int img_convert(int argc, char **argv)
>      QEMUOptionParameter *out_baseimg_param;
>      char *options = NULL;
>      const char *snapshot_name = NULL;
> -    int min_sparse = 8; /* Need at least 4k of zeros for sparse detection */
> +    int min_sparse = 128; /* Need at least 64k of zeros for sparse detection */
>      bool quiet = false;
>      Error *local_err = NULL;
>  
> diff --git a/qemu-img.texi b/qemu-img.texi
> index cb4a3eb..c0e86ab 100644
> --- a/qemu-img.texi
> +++ b/qemu-img.texi
> @@ -195,7 +195,7 @@ Image conversion is also useful to get smaller image when using a
>  growable format such as @code{qcow} or @code{cow}: the empty sectors
>  are detected and suppressed from the destination image.
>  
> -@var{sparse_size} indicates the consecutive number of bytes (defaults to 4k)
> +@var{sparse_size} indicates the consecutive number of bytes (defaults to 64k)
>  that must contain only zeros for qemu-img to create a sparse image during
>  conversion. If @var{sparse_size} is 0, the source will not be scanned for
>  unallocated or zero sectors, and the destination image will always be
> 

Reviewed-by: Paolo Bonzini <pbonzini@redhat.com>
diff --git a/qemu-img.texi b/qemu-img.texi
index cb4a3eb..c0e86ab 100644
--- a/qemu-img.texi
+++ b/qemu-img.texi
@@ -195,7 +195,7 @@  Image conversion is also useful to get smaller image when using a
 growable format such as @code{qcow} or @code{cow}: the empty sectors
 are detected and suppressed from the destination image.
 
-@var{sparse_size} indicates the consecutive number of bytes (defaults to 4k)
+@var{sparse_size} indicates the consecutive number of bytes (defaults to 64k)
 that must contain only zeros for qemu-img to create a sparse image during
 conversion. If @var{sparse_size} is 0, the source will not be scanned for
 unallocated or zero sectors, and the destination image will always be
diff mbox

Patch

diff --git a/qemu-img.c b/qemu-img.c
index cc7540f..6f1179b 100644
--- a/qemu-img.c
+++ b/qemu-img.c
@@ -101,7 +101,7 @@  static void help(void)
            "  '-p' show progress of command (only certain commands)\n"
            "  '-pp' show progress of command in sectors (only convert command)\n"
            "  '-q' use Quiet mode - do not print any output (except errors)\n"
-           "  '-S' indicates the consecutive number of bytes (defaults to 4k) that must\n"
+           "  '-S' indicates the consecutive number of bytes (defaults to 64k) that must\n"
            "       contain only zeros for qemu-img to create a sparse image during\n"
            "       conversion. If the number of bytes is 0, the source will not be scanned for\n"
            "       unallocated or zero sectors, and the destination image will always be\n"
@@ -1158,7 +1158,7 @@  static int img_convert(int argc, char **argv)
     QEMUOptionParameter *out_baseimg_param;
     char *options = NULL;
     const char *snapshot_name = NULL;
-    int min_sparse = 8; /* Need at least 4k of zeros for sparse detection */
+    int min_sparse = 128; /* Need at least 64k of zeros for sparse detection */
     bool quiet = false;
     Error *local_err = NULL;
 